Nodes
=====

.. currentmodule:: pywr.nodes


Nodes classes
-------------

Nodes that are instantiable by the user

.. autosummary::
   :toctree: generated/

   Node
   Link
   Input
   Output
   BreakLink
   LossLink
   PiecewiseLink
   MultiSplitLink
   Storage
   VirtualStorage
   RollingVirtualStorage
   AnnualVirtualStorage
   SeasonalVirtualStorage
   AggregatedStorage
   AggregatedNode
   DelayNode

.. currentmodule:: pywr.domains.river

River domain nodes

.. autosummary::
   :toctree: generated/

   Catchment
   Reservoir
   River
   RiverSplit
   RiverSplitWithGauge
   RiverGauge


